@@ -1,6 +1,6 @@
 import time
 import boto3
-from zip_util import *
+from JT_AWS.zip_util import *
 
 try:
     import paramiko
